core.stopwatch — PyZMQ v2.1.1dev documentation

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »

# core.stopwatch

## Module: `core.stopwatch`

Inheritance diagram for `zmq.core.stopwatch`:

0MQ Stopwatch class.

## `Stopwatch`

class `zmq.core.stopwatch.` `Stopwatch`

  Bases: `object`

  A simple stopwatch based on zmq_stopwatch_start/stop.

  This class should be used for benchmarking and timing 0MQ code.

  `sleep`(seconds)

    Sleep for a number of seconds.

  `start`()

    Start the stopwatch.

  `stop`()

    Stop the stopwatch.

### Navigation

- index
- modules |
- next |
- previous |
- home|
- search|
- API »
- The PyZMQ API »